/*
 * Copyright (c) 2002, 2003, 2004 Active Endpoints, Inc.
 *
 * This program is licensed under the terms of the GNU General Public License
 * Version 2 (the "License") as published by the Free Software Foundation, and 
 * the ActiveBPEL Licensing Policies (the "Policies").  A copy of the License
 * and the Policies were distributed with this program.  
 *
 * The License is available at:
 * http://www.gnu.org/copyleft/gpl.html
 *
 * The Policies are available at:
 * http://www.activebpel.org/licensing/index.html
 *
 * Unless required by applicable law or agreed to in writing, this program is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License and the Policies for
 * specific language governing the use of this program.
 */
package org.activebpel.demo;
import org.activebpel.demo.Constants;
import org.apache.axis.AxisFault;
import javax.xml.namespace.QName;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.apache.axis.utils.XMLUtils;

/**
 * The fault thrown by the Web services.
 * 
 * @author Jim Menard, <a href="mailto:jimm@activebpel.org">jimm@activebpel.org</a>
 */
public class loanProcessFault extends AxisFault {

protected static final String DETAIL_ELEMENT_NAME = "errorCode";

/**
 * Returns <code>true</code> if this fault has the magic fault error code. By
 * the time a client receives the fault from a Web service, it is no longer a
 * <code>loanProcessFault</code>. That's why this is a class method instead of
 * an instance method.
 *
 * @return <code>true</code> if this fault has the magic fault error code
 */
public static boolean hasMagicFaultErrorCode(AxisFault e) {
    Element[] details = e.getFaultDetails();
    if (details.length != 1)
	return false;
    Element detail = details[0];
    if (!DETAIL_ELEMENT_NAME.equals(detail.getNodeName()))
	return false;

    Node text = detail.getFirstChild();
    return text != null &&
	Constants.MAGIC_FAULT_ERROR_CODE_STRING.equals(text.getNodeValue());
}

/**
 * Used by constructors to create the fault details containing the error code.
 * <var>code</var> must be a string representation of a
 * <code>BigInteger</code>.
 *
 * @param code the error code as a string
 */
protected static Element[] details(String code) {
    Element[] details = new Element[1];
    details[0] = XMLUtils.StringToElement("", DETAIL_ELEMENT_NAME, code);
    return details;
}

/**
 * Constructor. Creates a fault with a simple error message and the error code
 * <code>Constants.MAGIC_FAULT_ERROR_CODE_STRING)</code>.
 *
 * @param whichNamespace either "approver" or "assessor"
 */
public loanProcessFault(String whichNamespace) {
    this(whichNamespace, whichNamespace + " fault thrown purposefully",
	 Constants.MAGIC_FAULT_ERROR_CODE_STRING);
}

/**
 * Constructor. Creates a fault with the given <var>message</var> and error
 * <var>code</var>. <var>code</var> must be a string representation of a
 * <code>BigInteger</code>.
 *
 * @param whichNamespace either "approver" or "assessor"
 * @param message the fault message string
 * @param code the error code as a string
 */
public loanProcessFault(String whichNamespace, String message, String code) {
    super(new QName("http://tempuri.org/services/loan" + whichNamespace, "loanProcessFault"),
	  message, "", details(code));
}

}
